# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/gateway.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/gateway.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import account_pb2 as gateway_dot_account__pb2
from . import api_key_pb2 as gateway_dot_api__key__pb2
from . import audit_log_pb2 as gateway_dot_audit__log__pb2
from . import aws_iam_role_binding_pb2 as gateway_dot_aws__iam__role__binding__pb2
from . import batch_inference_job_pb2 as gateway_dot_batch__inference__job__pb2
from . import batch_job_pb2 as gateway_dot_batch__job__pb2
from . import billing_pb2 as gateway_dot_billing__pb2
from . import cluster_pb2 as gateway_dot_cluster__pb2
from . import dataset_pb2 as gateway_dot_dataset__pb2
from . import dataset_validation_job_pb2 as gateway_dot_dataset__validation__job__pb2
from . import deployed_model_pb2 as gateway_dot_deployed__model__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import deployment_template_pb2 as gateway_dot_deployment__template__pb2
from . import eagle_training_job_pb2 as gateway_dot_eagle__training__job__pb2
from . import environment_pb2 as gateway_dot_environment__pb2
from . import evaluation_pb2 as gateway_dot_evaluation__pb2
from . import evaluation_job_pb2 as gateway_dot_evaluation__job__pb2
from . import evaluator_pb2 as gateway_dot_evaluator__pb2
from . import feature_flag_pb2 as gateway_dot_feature__flag__pb2
from . import fine_tuning_job_pb2 as gateway_dot_fine__tuning__job__pb2
from . import inference_log_pb2 as gateway_dot_inference__log__pb2
from . import model_pb2 as gateway_dot_model__pb2
from . import node_pool_pb2 as gateway_dot_node__pool__pb2
from . import node_pool_binding_pb2 as gateway_dot_node__pool__binding__pb2
from . import peft_merge_job_pb2 as gateway_dot_peft__merge__job__pb2
from . import quota_pb2 as gateway_dot_quota__pb2
from . import reinforcement_fine_tuning_epoch_pb2 as gateway_dot_reinforcement__fine__tuning__epoch__pb2
from . import reinforcement_fine_tuning_job_pb2 as gateway_dot_reinforcement__fine__tuning__job__pb2
from . import reservation_pb2 as gateway_dot_reservation__pb2
from . import rlor_trainer_job_pb2 as gateway_dot_rlor__trainer__job__pb2
from . import secret_pb2 as gateway_dot_secret__pb2
from . import sign_in_pb2 as gateway_dot_sign__in__pb2
from . import snapshot_pb2 as gateway_dot_snapshot__pb2
from . import supervised_fine_tuning_job_pb2 as gateway_dot_supervised__fine__tuning__job__pb2
from . import user_pb2 as gateway_dot_user__pb2
from ..google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ..google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/gateway.proto\x12\x07gateway\x1a\x15gateway/account.proto\x1a\x15gateway/api_key.proto\x1a\x17gateway/audit_log.proto\x1a\"gateway/aws_iam_role_binding.proto\x1a!gateway/batch_inference_job.proto\x1a\x17gateway/batch_job.proto\x1a\x15gateway/billing.proto\x1a\x15gateway/cluster.proto\x1a\x15gateway/dataset.proto\x1a$gateway/dataset_validation_job.proto\x1a\x1cgateway/deployed_model.proto\x1a\x18gateway/deployment.proto\x1a!gateway/deployment_template.proto\x1a gateway/eagle_training_job.proto\x1a\x19gateway/environment.proto\x1a\x18gateway/evaluation.proto\x1a\x1cgateway/evaluation_job.proto\x1a\x17gateway/evaluator.proto\x1a\x1agateway/feature_flag.proto\x1a\x1dgateway/fine_tuning_job.proto\x1a\x1bgateway/inference_log.proto\x1a\x13gateway/model.proto\x1a\x17gateway/node_pool.proto\x1a\x1fgateway/node_pool_binding.proto\x1a\x1cgateway/peft_merge_job.proto\x1a\x13gateway/quota.proto\x1a-gateway/reinforcement_fine_tuning_epoch.proto\x1a+gateway/reinforcement_fine_tuning_job.proto\x1a\x19gateway/reservation.proto\x1a\x1egateway/rlor_trainer_job.proto\x1a\x14gateway/secret.proto\x1a\x15gateway/sign_in.proto\x1a\x16gateway/snapshot.proto\x1a(gateway/supervised_fine_tuning_job.proto\x1a\x12gateway/user.proto\x1a\x1cgoogle/api/annotations.proto\x1a#google/longrunning/operations.proto\x1a\x1bgoogle/protobuf/empty.proto2\x93\xa5\x01\n\x07Gateway\x12\\\n\x11GetOAuthArguments\x12!.gateway.GetOAuthArgumentsRequest\x1a\".gateway.GetOAuthArgumentsResponse\"\x00\x12\x42\n\rCreateAccount\x12\x1d.gateway.CreateAccountRequest\x1a\x10.gateway.Account\"\x00\x12Y\n\nGetAccount\x12\x1a.gateway.GetAccountRequest\x1a\x10.gateway.Account\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/{name=accounts/*}\x12\x61\n\x0cListAccounts\x12\x1c.gateway.ListAccountsRequest\x1a\x1d.gateway.ListAccountsResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/accounts\x12\x42\n\rUpdateAccount\x12\x1d.gateway.UpdateAccountRequest\x1a\x10.gateway.Account\"\x00\x12H\n\rDeleteAccount\x12\x1d.gateway.DeleteAccountRequest\x1a\x16.google.protobuf.Empty\"\x00\x12<\n\nGetBalance\x12\x1a.gateway.GetBalanceRequest\x1a\x10.gateway.Balance\"\x00\x12_\n\x12ListPaymentMethods\x12\".gateway.ListPaymentMethodsRequest\x1a#.gateway.ListPaymentMethodsResponse\"\x00\x12\x44\n\tListCosts\x12\x19.gateway.ListCostsRequest\x1a\x1a.gateway.ListCostsResponse\"\x00\x12M\n\x0cListInvoices\x12\x1c.gateway.ListInvoicesRequest\x1a\x1d.gateway.ListInvoicesResponse\"\x00\x12\x65\n\x14\x45xportBillingMetrics\x12$.gateway.ExportBillingMetricsRequest\x1a%.gateway.ExportBillingMetricsResponse\"\x00\x12n\n\x17GetTotalHistoricalSpend\x12\'.gateway.GetTotalHistoricalSpendRequest\x1a(.gateway.GetTotalHistoricalSpendResponse\"\x00\x12y\n\x0e\x43reateBatchJob\x12\x1e.gateway.CreateBatchJobRequest\x1a\x11.gateway.BatchJob\"4\x82\xd3\xe4\x93\x02.\"!/v1/{parent=accounts/*}/batchJobs:\tbatch_job\x12h\n\x0bGetBatchJob\x12\x1b.gateway.GetBatchJobRequest\x1a\x11.gateway.BatchJob\")\x82\xd3\xe4\x93\x02#\x12!/v1/{name=accounts/*/batchJobs/*}\x12y\n\rListBatchJobs\x12\x1d.gateway.ListBatchJobsRequest\x1a\x1e.gateway.ListBatchJobsResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/{parent=accounts/*}/batchJobs\x12\x83\x01\n\x0eUpdateBatchJob\x12\x1e.gateway.UpdateBatchJobRequest\x1a\x11.gateway.BatchJob\">\x82\xd3\xe4\x93\x02\x38\x32+/v1/{batch_job.name=accounts/*/batchJobs/*}:\tbatch_job\x12s\n\x0e\x44\x65leteBatchJob\x12\x1e.gateway.DeleteBatchJobRequest\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/v1/{name=accounts/*/batchJobs/*}\x12\x8e\x01\n\x14\x42\x61tchDeleteBatchJobs\x12$.gateway.BatchDeleteBatchJobsRequest\x1a\x16.google.protobuf.Empty\"8\x82\xd3\xe4\x93\x02\x32\"-/v1/{parent=accounts/*}/batchJobs:batchDelete:\x01*\x12}\n\x0e\x43\x61ncelBatchJob\x12\x1e.gateway.CancelBatchJobRequest\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-\"(/v1/{name=accounts/*/batchJobs/*}:cancel:\x01*\x12m\n\rCreateCluster\x12\x1d.gateway.CreateClusterRequest\x1a\x10.gateway.Cluster\"+\x82\xd3\xe4\x93\x02%\" /v1/{parent=accounts/*}/clusters:\x01*\x12\x64\n\nGetCluster\x12\x1a.gateway.GetClusterRequest\x1a\x10.gateway.Cluster\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/{name=accounts/*/clusters/*}\x12u\n\x0cListClusters\x12\x1c.gateway.ListClustersRequest\x1a\x1d.gateway.ListClustersResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/{parent=accounts/*}/clusters\x12{\n\rUpdateCluster\x12\x1d.gateway.UpdateClusterRequest\x1a\x10.gateway.Cluster\"9\x82\xd3\xe4\x93\x02\x33\x32(/v1/{cluster.name=accounts/*/clusters/*}:\x07\x63luster\x12p\n\rDeleteCluster\x12\x1d.gateway.DeleteClusterRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"* /v1/{name=accounts/*/clusters/*}\x12\xa0\x01\n\x18GetClusterConnectionInfo\x12(.gateway.GetClusterConnectionInfoRequest\x1a\x1e.gateway.ClusterConnectionInfo\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v1/{name=accounts/*/clusters/*}:getConnectionInfo\x12}\n\x11\x43reateEnvironment\x12!.gateway.CreateEnvironmentRequest\x1a\x14.gateway.Environment\"/\x82\xd3\xe4\x93\x02)\"$/v1/{parent=accounts/*}/environments:\x01*\x12t\n\x0eGetEnvironment\x12\x1e.gateway.GetEnvironmentRequest\x1a\x14.gateway.Environment\",\x82\xd3\xe4\x93\x02&\x12$/v1/{name=accounts/*/environments/*}\x12\x85\x01\n\x10ListEnvironments\x12 .gateway.ListEnvironmentsRequest\x1a!.gateway.ListEnvironmentsResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/{parent=accounts/*}/environments\x12\x93\x01\n\x11UpdateEnvironment\x12!.gateway.UpdateEnvironmentRequest\x1a\x14.gateway.Environment\"E\x82\xd3\xe4\x93\x02?20/v1/{environment.name=accounts/*/environments/*}:\x0b\x65nvironment\x12|\n\x11\x44\x65leteEnvironment\x12!.gateway.DeleteEnvironmentRequest\x1a\x16.google.protobuf.Empty\",\x82\xd3\xe4\x93\x02&*$/v1/{name=accounts/*/environments/*}\x12\x97\x01\n\x17\x42\x61tchDeleteEnvironments\x12\'.gateway.BatchDeleteEnvironmentsRequest\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35\"0/v1/{parent=accounts/*}/environments:batchDelete:\x01*\x12\x89\x01\n\x12\x43onnectEnvironment\x12\".gateway.ConnectEnvironmentRequest\x1a\x16.google.protobuf.Empty\"7\x82\xd3\xe4\x93\x02\x31\",/v1/{name=accounts/*/environments/*}:connect:\x01*\x12\x92\x01\n\x15\x44isconnectEnvironment\x12%.gateway.DisconnectEnvironmentRequest\x1a\x16.google.protobuf.Empty\":\x82\xd3\xe4\x93\x02\x34\"//v1/{name=accounts/*/environments/*}:disconnect:\x01*\x12H\n\x0eGetFeatureFlag\x12\x1e.gateway.GetFeatureFlagRequest\x1a\x14.gateway.FeatureFlag\"\x00\x12Y\n\x10ListFeatureFlags\x12 .gateway.ListFeatureFlagsRequest\x1a!.gateway.ListFeatureFlagsResponse\"\x00\x12x\n\x0e\x43reateSnapshot\x12\x1e.gateway.CreateSnapshotRequest\x1a\x11.gateway.Snapshot\"3\x82\xd3\xe4\x93\x02-\"!/v1/{parent=accounts/*}/snapshots:\x08snapshot\x12h\n\x0bGetSnapshot\x12\x1b.gateway.GetSnapshotRequest\x1a\x11.gateway.Snapshot\")\x82\xd3\xe4\x93\x02#\x12!/v1/{name=accounts/*/snapshots/*}\x12y\n\rListSnapshots\x12\x1d.gateway.ListSnapshotsRequest\x1a\x1e.gateway.ListSnapshotsResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/{parent=accounts/*}/snapshots\x12s\n\x0e\x44\x65leteSnapshot\x12\x1e.gateway.DeleteSnapshotRequest\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/v1/{name=accounts/*/snapshots/*}\x12\x87\x01\n\x0fGetBatchJobLogs\x12\x1f.gateway.GetBatchJobLogsRequest\x1a .gateway.GetBatchJobLogsResponse\"1\x82\xd3\xe4\x93\x02+\x12)/v1/{name=accounts/*/batchJobs/*}:getLogs\x12q\n\x0e\x43reateNodePool\x12\x1e.gateway.CreateNodePoolRequest\x1a\x11.gateway.NodePool\",\x82\xd3\xe4\x93\x02&\"!/v1/{parent=accounts/*}/nodePools:\x01*\x12h\n\x0bGetNodePool\x12\x1b.gateway.GetNodePoolRequest\x1a\x11.gateway.NodePool\")\x82\xd3\xe4\x93\x02#\x12!/v1/{name=accounts/*/nodePools/*}\x12y\n\rListNodePools\x12\x1d.gateway.ListNodePoolsRequest\x1a\x1e.gateway.ListNodePoolsResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/{parent=accounts/*}/nodePools\x12\x83\x01\n\x0eUpdateNodePool\x12\x1e.gateway.UpdateNodePoolRequest\x1a\x11.gateway.NodePool\">\x82\xd3\xe4\x93\x02\x38\x32+/v1/{node_pool.name=accounts/*/nodePools/*}:\tnode_pool\x12s\n\x0e\x44\x65leteNodePool\x12\x1e.gateway.DeleteNodePoolRequest\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/v1/{name=accounts/*/nodePools/*}\x12\x8e\x01\n\x14\x42\x61tchDeleteNodePools\x12$.gateway.BatchDeleteNodePoolsRequest\x1a\x16.google.protobuf.Empty\"8\x82\xd3\xe4\x93\x02\x32\"-/v1/{parent=accounts/*}/nodePools:batchDelete:\x01*\x12\x80\x01\n\x10GetNodePoolStats\x12 .gateway.GetNodePoolStatsRequest\x1a\x16.gateway.NodePoolStats\"2\x82\xd3\xe4\x93\x02,\x12*/v1/{name=accounts/*/nodePools/*}:getStats\x12\x64\n\nCreateUser\x12\x1a.gateway.CreateUserRequest\x1a\r.gateway.User\"+\x82\xd3\xe4\x93\x02%\"\x1d/v1/{parent=accounts/*}/users:\x04user\x12X\n\x07GetUser\x12\x17.gateway.GetUserRequest\x1a\r.gateway.User\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/{name=accounts/*/users/*}\x12i\n\tListUsers\x12\x19.gateway.ListUsersRequest\x1a\x1a.gateway.ListUsersResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/{parent=accounts/*}/users\x12i\n\nUpdateUser\x12\x1a.gateway.UpdateUserRequest\x1a\r.gateway.User\"0\x82\xd3\xe4\x93\x02*2\"/v1/{user.name=accounts/*/users/*}:\x04user\x12\x42\n\nDeleteUser\x12\x1a.gateway.DeleteUserRequest\x1a\x16.google.protobuf.Empty\"\x00\x12y\n\rListAuditLogs\x12\x1d.gateway.ListAuditLogsRequest\x1a\x1e.gateway.ListAuditLogsResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/{parent=accounts/*}/auditLogs\x12i\n\x0c\x43reateApiKey\x12\x1c.gateway.CreateApiKeyRequest\x1a\x0f.gateway.ApiKey\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/{parent=accounts/*}/apiKeys:\x01*\x12q\n\x0bListApiKeys\x12\x1b.gateway.ListApiKeysRequest\x1a\x1c.gateway.ListApiKeysResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/{parent=accounts/*}/apiKeys\x12w\n\x0c\x44\x65leteApiKey\x12\x1c.gateway.DeleteApiKeyRequest\x1a\x16.google.protobuf.Empty\"1\x82\xd3\xe4\x93\x02+\"&/v1/{parent=accounts/*}/apiKeys:delete:\x01*\x12I\n\x11GetInternalApiKey\x12!.gateway.GetInternalApiKeyRequest\x1a\x0f.gateway.ApiKey\"\x00\x12\x65\n\x0b\x43reateModel\x12\x1b.gateway.CreateModelRequest\x1a\x0e.gateway.Model\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/{parent=accounts/*}/models:\x01*\x12\\\n\x08GetModel\x12\x18.gateway.GetModelRequest\x1a\x0e.gateway.Model\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/{name=accounts/*/models/*}\x12m\n\nListModels\x12\x1a.gateway.ListModelsRequest\x1a\x1b.gateway.ListModelsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/{parent=accounts/*}/models\x12q\n\x18ListServerlessLoraModels\x12(.gateway.ListServerlessLoraModelsRequest\x1a).gateway.ListServerlessLoraModelsResponse\"\x00\x12o\n\x0bUpdateModel\x12\x1b.gateway.UpdateModelRequest\x1a\x0e.gateway.Model\"3\x82\xd3\xe4\x93\x02-2$/v1/{model.name=accounts/*/models/*}:\x05model\x12j\n\x0b\x44\x65leteModel\x12\x1b.gateway.DeleteModelRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 *\x1e/v1/{name=accounts/*/models/*}\x12\xa6\x01\n\x16GetModelUploadEndpoint\x12&.gateway.GetModelUploadEndpointRequest\x1a\'.gateway.GetModelUploadEndpointResponse\";\x82\xd3\xe4\x93\x02\x35\"0/v1/{name=accounts/*/models/*}:getUploadEndpoint:\x01*\x12\xab\x01\n\x18GetModelDownloadEndpoint\x12(.gateway.GetModelDownloadEndpointRequest\x1a).gateway.GetModelDownloadEndpointResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v1/{name=accounts/*/models/*}:getDownloadEndpoint\x12\x89\x01\n\x13ValidateModelUpload\x12#.gateway.ValidateModelUploadRequest\x1a\x16.google.protobuf.Empty\"5\x82\xd3\xe4\x93\x02/\x12-/v1/{name=accounts/*/models/*}:validateUpload\x12v\n\x13ValidateModelConfig\x12#.gateway.ValidateModelConfigRequest\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/validateModelConfig:\x01*\x12{\n\x0bImportModel\x12\x1b.gateway.ImportModelRequest\x1a\x1d.google.longrunning.Operation\"0\x82\xd3\xe4\x93\x02*\"%/v1/{name=accounts/*/models/*}:import:\x01*\x12\x82\x01\n\x10\x43reateDeployment\x12 .gateway.CreateDeploymentRequest\x1a\x13.gateway.Deployment\"7\x82\xd3\xe4\x93\x02\x31\"#/v1/{parent=accounts/*}/deployments:\ndeployment\x12p\n\rGetDeployment\x12\x1d.gateway.GetDeploymentRequest\x1a\x13.gateway.Deployment\"+\x82\xd3\xe4\x93\x02%\x12#/v1/{name=accounts/*/deployments/*}\x12\x81\x01\n\x0fListDeployments\x12\x1f.gateway.ListDeploymentsRequest\x1a .gateway.ListDeploymentsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/{parent=accounts/*}/deployments\x12\x8d\x01\n\x10UpdateDeployment\x12 .gateway.UpdateDeploymentRequest\x1a\x13.gateway.Deployment\"B\x82\xd3\xe4\x93\x02<2./v1/{deployment.name=accounts/*/deployments/*}:\ndeployment\x12y\n\x10\x44\x65leteDeployment\x12 .gateway.DeleteDeploymentRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%*#/v1/{name=accounts/*/deployments/*}\x12\x86\x01\n\x12UndeleteDeployment\x12\".gateway.UndeleteDeploymentRequest\x1a\x13.gateway.Deployment\"7\x82\xd3\xe4\x93\x02\x31\",/v1/{name=accounts/*/deployments/*}:undelete:\x01*\x12\x80\x01\n\x0fScaleDeployment\x12\x1f.gateway.ScaleDeploymentRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.2)/v1/{name=accounts/*/deployments/*}:scale:\x01*\x12\x98\x01\n\x14GetDeploymentMetrics\x12$.gateway.GetDeploymentMetricsRequest\x1a%.gateway.GetDeploymentMetricsResponse\"3\x82\xd3\xe4\x93\x02-\x12+/v1/{name=accounts/*/deployments/*}:metrics\x12\x63\n\x18\x43reateDeploymentTemplate\x12(.gateway.CreateDeploymentTemplateRequest\x1a\x1b.gateway.DeploymentTemplate\"\x00\x12]\n\x15GetDeploymentTemplate\x12%.gateway.GetDeploymentTemplateRequest\x1a\x1b.gateway.DeploymentTemplate\"\x00\x12n\n\x17ListDeploymentTemplates\x12\'.gateway.ListDeploymentTemplatesRequest\x1a(.gateway.ListDeploymentTemplatesResponse\"\x00\x12\x63\n\x18UpdateDeploymentTemplate\x12(.gateway.UpdateDeploymentTemplateRequest\x1a\x1b.gateway.DeploymentTemplate\"\x00\x12^\n\x18\x44\x65leteDeploymentTemplate\x12(.gateway.DeleteDeploymentTemplateRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x92\x01\n\x13\x43reateDeployedModel\x12#.gateway.CreateDeployedModelRequest\x1a\x16.gateway.DeployedModel\">\x82\xd3\xe4\x93\x02\x38\"&/v1/{parent=accounts/*}/deployedModels:\x0e\x64\x65ployed_model\x12|\n\x10GetDeployedModel\x12 .gateway.GetDeployedModelRequest\x1a\x16.gateway.DeployedModel\".\x82\xd3\xe4\x93\x02(\x12&/v1/{name=accounts/*/deployedModels/*}\x12\x8d\x01\n\x12ListDeployedModels\x12\".gateway.ListDeployedModelsRequest\x1a#.gateway.ListDeployedModelsResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/{parent=accounts/*}/deployedModels\x12\xa1\x01\n\x13UpdateDeployedModel\x12#.gateway.UpdateDeployedModelRequest\x1a\x16.gateway.DeployedModel\"M\x82\xd3\xe4\x93\x02G25/v1/{deployed_model.name=accounts/*/deployedModels/*}:\x0e\x64\x65ployed_model\x12\x82\x01\n\x13\x44\x65leteDeployedModel\x12#.gateway.DeleteDeployedModelRequest\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(*&/v1/{name=accounts/*/deployedModels/*}\x12\xa8\x01\n\x17\x43reateAwsIamRoleBinding\x12\'.gateway.CreateAwsIamRoleBindingRequest\x1a\x1a.gateway.AwsIamRoleBinding\"H\x82\xd3\xe4\x93\x02\x42\"*/v1/{parent=accounts/*}/awsIamRoleBindings:\x14\x61ws_iam_role_binding\x12\x9d\x01\n\x16ListAwsIamRoleBindings\x12&.gateway.ListAwsIamRoleBindingsRequest\x1a\'.gateway.ListAwsIamRoleBindingsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/v1/{parent=accounts/*}/awsIamRoleBindings\x12\xc4\x01\n\x17\x44\x65leteAwsIamRoleBinding\x12\'.gateway.DeleteAwsIamRoleBindingRequest\x1a\x16.google.protobuf.Empty\"h\x82\xd3\xe4\x93\x02\x62\"J/v1/{aws_iam_role_binding.account_id=accounts/*}/awsIamRoleBindings:delete:\x14\x61ws_iam_role_binding\x12\x9d\x01\n\x15\x43reateNodePoolBinding\x12%.gateway.CreateNodePoolBindingRequest\x1a\x18.gateway.NodePoolBinding\"C\x82\xd3\xe4\x93\x02=\"(/v1/{parent=accounts/*}/nodePoolBindings:\x11node_pool_binding\x12\x95\x01\n\x14ListNodePoolBindings\x12$.gateway.ListNodePoolBindingsRequest\x1a%.gateway.ListNodePoolBindingsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/v1/{parent=accounts/*}/nodePoolBindings\x12\xb8\x01\n\x15\x44\x65leteNodePoolBinding\x12%.gateway.DeleteNodePoolBindingRequest\x1a\x16.google.protobuf.Empty\"`\x82\xd3\xe4\x93\x02Z\"E/v1/{node_pool_binding.account_id=accounts/*}/nodePoolBindings:delete:\x11node_pool_binding\x12m\n\rCreateDataset\x12\x1d.gateway.CreateDatasetRequest\x1a\x10.gateway.Dataset\"+\x82\xd3\xe4\x93\x02%\" /v1/{parent=accounts/*}/datasets:\x01*\x12\x64\n\nGetDataset\x12\x1a.gateway.GetDatasetRequest\x1a\x10.gateway.Dataset\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/{name=accounts/*/datasets/*}\x12u\n\x0cListDatasets\x12\x1c.gateway.ListDatasetsRequest\x1a\x1d.gateway.ListDatasetsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/{parent=accounts/*}/datasets\x12{\n\rUpdateDataset\x12\x1d.gateway.UpdateDatasetRequest\x1a\x10.gateway.Dataset\"9\x82\xd3\xe4\x93\x02\x33\x32(/v1/{dataset.name=accounts/*/datasets/*}:\x07\x64\x61taset\x12p\n\rDeleteDataset\x12\x1d.gateway.DeleteDatasetRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"* /v1/{name=accounts/*/datasets/*}\x12P\n\rUploadDataset\x12\x1d.gateway.UploadDatasetRequest\x1a\x1e.gateway.UploadDatasetResponse\"\x00\x12\xae\x01\n\x18GetDatasetUploadEndpoint\x12(.gateway.GetDatasetUploadEndpointRequest\x1a).gateway.GetDatasetUploadEndpointResponse\"=\x82\xd3\xe4\x93\x02\x37\"2/v1/{name=accounts/*/datasets/*}:getUploadEndpoint:\x01*\x12\x92\x01\n\x15ValidateDatasetUpload\x12%.gateway.ValidateDatasetUploadRequest\x1a\x16.google.protobuf.Empty\":\x82\xd3\xe4\x93\x02\x34\"//v1/{name=accounts/*/datasets/*}:validateUpload:\x01*\x12\xb3\x01\n\x1aGetDatasetDownloadEndpoint\x12*.gateway.GetDatasetDownloadEndpointRequest\x1a+.gateway.GetDatasetDownloadEndpointResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/v1/{name=accounts/*/datasets/*}:getDownloadEndpoint\x12Q\n\x0ePreviewDataset\x12\x1e.gateway.PreviewDatasetRequest\x1a\x1f.gateway.PreviewDatasetResponse\x12u\n\x0f\x43reateEvaluator\x12\x1f.gateway.CreateEvaluatorRequest\x1a\x12.gateway.Evaluator\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/{parent=accounts/*}/evaluators:\x01*\x12l\n\x0cGetEvaluator\x12\x1c.gateway.GetEvaluatorRequest\x1a\x12.gateway.Evaluator\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/{name=accounts/*/evaluators/*}\x12}\n\x0eListEvaluators\x12\x1e.gateway.ListEvaluatorsRequest\x1a\x1f.gateway.ListEvaluatorsResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/{parent=accounts/*}/evaluators\x12v\n\x0f\x44\x65leteEvaluator\x12\x1f.gateway.DeleteEvaluatorRequest\x1a\x16.google.protobuf.Empty\"*\x82\xd3\xe4\x93\x02$*\"/v1/{name=accounts/*/evaluators/*}\x12y\n\x10\x43reateEvaluation\x12 .gateway.CreateEvaluationRequest\x1a\x13.gateway.Evaluation\".\x82\xd3\xe4\x93\x02(\"#/v1/{parent=accounts/*}/evaluations:\x01*\x12p\n\rGetEvaluation\x12\x1d.gateway.GetEvaluationRequest\x1a\x13.gateway.Evaluation\"+\x82\xd3\xe4\x93\x02%\x12#/v1/{name=accounts/*/evaluations/*}\x12\x81\x01\n\x0fListEvaluations\x12\x1f.gateway.ListEvaluationsRequest\x1a .gateway.ListEvaluationsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/{parent=accounts/*}/evaluations\x12y\n\x10\x44\x65leteEvaluation\x12 .gateway.DeleteEvaluationRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%*#/v1/{name=accounts/*/evaluations/*}\x12\x85\x01\n\x13\x43reateEvaluationJob\x12#.gateway.CreateEvaluationJobRequest\x1a\x16.gateway.EvaluationJob\"1\x82\xd3\xe4\x93\x02+\"&/v1/{parent=accounts/*}/evaluationJobs:\x01*\x12|\n\x10GetEvaluationJob\x12 .gateway.GetEvaluationJobRequest\x1a\x16.gateway.EvaluationJob\".\x82\xd3\xe4\x93\x02(\x12&/v1/{name=accounts/*/evaluationJobs/*}\x12\x8d\x01\n\x12ListEvaluationJobs\x12\".gateway.ListEvaluationJobsRequest\x1a#.gateway.ListEvaluationJobsResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/{parent=accounts/*}/evaluationJobs\x12\x82\x01\n\x13\x44\x65leteEvaluationJob\x12#.gateway.DeleteEvaluationJobRequest\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(*&/v1/{name=accounts/*/evaluationJobs/*}\x12\x93\x01\n\x13\x43reateFineTuningJob\x12#.gateway.CreateFineTuningJobRequest\x1a\x16.gateway.FineTuningJob\"?\x82\xd3\xe4\x93\x02\x39\"&/v1/{parent=accounts/*}/fineTuningJobs:\x0f\x66ine_tuning_job\x12|\n\x10GetFineTuningJob\x12 .gateway.GetFineTuningJobRequest\x1a\x16.gateway.FineTuningJob\".\x82\xd3\xe4\x93\x02(\x12&/v1/{name=accounts/*/fineTuningJobs/*}\x12\x8d\x01\n\x12ListFineTuningJobs\x12\".gateway.ListFineTuningJobsRequest\x1a#.gateway.ListFineTuningJobsResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/{parent=accounts/*}/fineTuningJobs\x12\xa3\x01\n\x13UpdateFineTuningJob\x12#.gateway.UpdateFineTuningJobRequest\x1a\x16.gateway.FineTuningJob\"O\x82\xd3\xe4\x93\x02I26/v1/{fine_tuning_job.name=accounts/*/fineTuningJobs/*}:\x0f\x66ine_tuning_job\x12\x82\x01\n\x13\x44\x65leteFineTuningJob\x12#.gateway.DeleteFineTuningJobRequest\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(*&/v1/{name=accounts/*/fineTuningJobs/*}\x12\xc6\x01\n\x1d\x43reateSupervisedFineTuningJob\x12-.gateway.CreateSupervisedFineTuningJobRequest\x1a .gateway.SupervisedFineTuningJob\"T\x82\xd3\xe4\x93\x02N\"0/v1/{parent=accounts/*}/supervisedFineTuningJobs:\x1asupervised_fine_tuning_job\x12\xa4\x01\n\x1aGetSupervisedFineTuningJob\x12*.gateway.GetSupervisedFineTuningJobRequest\x1a .gateway.SupervisedFineTuningJob\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v1/{name=accounts/*/supervisedFineTuningJobs/*}\x12\xb5\x01\n\x1cListSupervisedFineTuningJobs\x12,.gateway.ListSupervisedFineTuningJobsRequest\x1a-.gateway.ListSupervisedFineTuningJobsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v1/{parent=accounts/*}/supervisedFineTuningJobs\x12\xa0\x01\n\x1d\x44\x65leteSupervisedFineTuningJob\x12-.gateway.DeleteSupervisedFineTuningJobRequest\x1a\x16.google.protobuf.Empty\"8\x82\xd3\xe4\x93\x02\x32*0/v1/{name=accounts/*/supervisedFineTuningJobs/*}\x12\xd5\x01\n CreateReinforcementFineTuningJob\x12\x30.gateway.CreateReinforcementFineTuningJobRequest\x1a#.gateway.ReinforcementFineTuningJob\"Z\x82\xd3\xe4\x93\x02T\"3/v1/{parent=accounts/*}/reinforcementFineTuningJobs:\x1dreinforcement_fine_tuning_job\x12\xb0\x01\n\x1dGetReinforcementFineTuningJob\x12-.gateway.GetReinforcementFineTuningJobRequest\x1a#.gateway.ReinforcementFineTuningJob\";\x82\xd3\xe4\x93\x02\x35\x12\x33/v1/{name=accounts/*/reinforcementFineTuningJobs/*}\x12\xc1\x01\n\x1fListReinforcementFineTuningJobs\x12/.gateway.ListReinforcementFineTuningJobsRequest\x1a\x30.gateway.ListReinforcementFineTuningJobsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/v1/{parent=accounts/*}/reinforcementFineTuningJobs\x12\xa9\x01\n DeleteReinforcementFineTuningJob\x12\x30.gateway.DeleteReinforcementFineTuningJobRequest\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35*3/v1/{name=accounts/*/reinforcementFineTuningJobs/*}\x12\x81\x01\n\"CreateReinforcementFineTuningEpoch\x12\x32.gateway.CreateReinforcementFineTuningEpochRequest\x1a%.gateway.ReinforcementFineTuningEpoch\"\x00\x12{\n\x1fGetReinforcementFineTuningEpoch\x12/.gateway.GetReinforcementFineTuningEpochRequest\x1a%.gateway.ReinforcementFineTuningEpoch\"\x00\x12\x8c\x01\n!ListReinforcementFineTuningEpochs\x12\x31.gateway.ListReinforcementFineTuningEpochsRequest\x1a\x32.gateway.ListReinforcementFineTuningEpochsResponse\"\x00\x12r\n\"DeleteReinforcementFineTuningEpoch\x12\x32.gateway.DeleteReinforcementFineTuningEpochRequest\x1a\x16.google.protobuf.Empty\"\x00\x12W\n\x14\x43reateRlorTrainerJob\x12$.gateway.CreateRlorTrainerJobRequest\x1a\x17.gateway.RlorTrainerJob\"\x00\x12Q\n\x11GetRlorTrainerJob\x12!.gateway.GetRlorTrainerJobRequest\x1a\x17.gateway.RlorTrainerJob\"\x00\x12\x62\n\x13ListRlorTrainerJobs\x12#.gateway.ListRlorTrainerJobsRequest\x1a$.gateway.ListRlorTrainerJobsResponse\"\x00\x12V\n\x14\x44\x65leteRlorTrainerJob\x12$.gateway.DeleteRlorTrainerJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x8e\x01\n\x12\x43reatePeftMergeJob\x12\".gateway.CreatePeftMergeJobRequest\x1a\x15.gateway.PeftMergeJob\"=\x82\xd3\xe4\x93\x02\x37\"%/v1/{parent=accounts/*}/PeftMergeJobs:\x0epeft_merge_job\x12x\n\x0fGetPeftMergeJob\x12\x1f.gateway.GetPeftMergeJobRequest\x1a\x15.gateway.PeftMergeJob\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/{name=accounts/*/PeftMergeJobs/*}\x12\x89\x01\n\x11ListPeftMergeJobs\x12!.gateway.ListPeftMergeJobsRequest\x1a\".gateway.ListPeftMergeJobsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/{parent=accounts/*}/PeftMergeJobs\x12\x7f\n\x12\x44\x65letePeftMergeJob\x12\".gateway.DeletePeftMergeJobRequest\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'*%/v1/{name=accounts/*/PeftMergeJobs/*}\x12\x36\n\x08GetQuota\x12\x18.gateway.GetQuotaRequest\x1a\x0e.gateway.Quota\"\x00\x12<\n\x0bUpdateQuota\x12\x1b.gateway.UpdateQuotaRequest\x1a\x0e.gateway.Quota\"\x00\x12G\n\nListQuotas\x12\x1a.gateway.ListQuotasRequest\x1a\x1b.gateway.ListQuotasResponse\"\x00\x12n\n\x0c\x43reateSecret\x12\x1c.gateway.CreateSecretRequest\x1a\x0f.gateway.Secret\"/\x82\xd3\xe4\x93\x02)\"\x1f/v1/{parent=accounts/*}/secrets:\x06secret\x12`\n\tGetSecret\x12\x19.gateway.GetSecretRequest\x1a\x0f.gateway.Secret\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/{name=accounts/*/secrets/*}\x12q\n\x0bListSecrets\x12\x1b.gateway.ListSecretsRequest\x1a\x1c.gateway.ListSecretsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/{parent=accounts/*}/secrets\x12u\n\x0cUpdateSecret\x12\x1c.gateway.UpdateSecretRequest\x1a\x0f.gateway.Secret\"6\x82\xd3\xe4\x93\x02\x30\x32&/v1/{secret.name=accounts/*/secrets/*}:\x06secret\x12m\n\x0c\x44\x65leteSecret\x12\x1c.gateway.DeleteSecretRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/{name=accounts/*/secrets/*}\x12H\n\x0eGetReservation\x12\x1e.gateway.GetReservationRequest\x1a\x14.gateway.Reservation\"\x00\x12Y\n\x10ListReservations\x12 .gateway.ListReservationsRequest\x1a!.gateway.ListReservationsResponse\"\x00\x12\x46\n\x0cPrepareModel\x12\x1c.gateway.PrepareModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12`\n\x17\x43reateBatchInferenceJob\x12\'.gateway.CreateBatchInferenceJobRequest\x1a\x1a.gateway.BatchInferenceJob\"\x00\x12Z\n\x14GetBatchInferenceJob\x12$.gateway.GetBatchInferenceJobRequest\x1a\x1a.gateway.BatchInferenceJob\"\x00\x12k\n\x16ListBatchInferenceJobs\x12&.gateway.ListBatchInferenceJobsRequest\x1a\'.gateway.ListBatchInferenceJobsResponse\"\x00\x12`\n\x17UpdateBatchInferenceJob\x12\'.gateway.UpdateBatchInferenceJobRequest\x1a\x1a.gateway.BatchInferenceJob\"\x00\x12\\\n\x17\x44\x65leteBatchInferenceJob\x12\'.gateway.DeleteBatchInferenceJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12]\n\x16\x43reateEagleTrainingJob\x12&.gateway.CreateEagleTrainingJobRequest\x1a\x19.gateway.EagleTrainingJob\"\x00\x12W\n\x13GetEagleTrainingJob\x12#.gateway.GetEagleTrainingJobRequest\x1a\x19.gateway.EagleTrainingJob\"\x00\x12h\n\x15ListEagleTrainingJobs\x12%.gateway.ListEagleTrainingJobsRequest\x1a&.gateway.ListEagleTrainingJobsResponse\"\x00\x12Z\n\x16\x44\x65leteEagleTrainingJob\x12&.gateway.DeleteEagleTrainingJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x9e\x01\n\'GetBatchInferenceJobInputUploadEndpoint\x12\x37.gateway.GetBatchInferenceJobInputUploadEndpointRequest\x1a\x38.gateway.GetBatchInferenceJobInputUploadEndpointResponse\"\x00\x12\xa7\x01\n*GetBatchInferenceJobOutputDownloadEndpoint\x12:.gateway.GetBatchInferenceJobOutputDownloadEndpointRequest\x1a;.gateway.GetBatchInferenceJobOutputDownloadEndpointResponse\"\x00\x12v\n$ValidateBatchInferenceJobInputUpload\x12\x34.gateway.ValidateBatchInferenceJobInputUploadRequest\x1a\x16.google.protobuf.Empty\"\x00\x12i\n\x1a\x43reateDatasetValidationJob\x12*.gateway.CreateDatasetValidationJobRequest\x1a\x1d.gateway.DatasetValidationJob\"\x00\x12\x63\n\x17GetDatasetValidationJob\x12\'.gateway.GetDatasetValidationJobRequest\x1a\x1d.gateway.DatasetValidationJob\"\x00\x12t\n\x19ListDatasetValidationJobs\x12).gateway.ListDatasetValidationJobsRequest\x1a*.gateway.ListDatasetValidationJobsResponse\"\x00\x12\x62\n\x1a\x44\x65leteDatasetValidationJob\x12*.gateway.DeleteDatasetValidationJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x12ValidateAssertions\x12\".gateway.ValidateAssertionsRequest\x1a#.gateway.ValidateAssertionsResponse\"A\x82\xd3\xe4\x93\x02;\"6/v1/{parent=accounts/*}/evaluations:validateAssertions:\x01*\x12\x97\x01\n\x10PreviewEvaluator\x12 .gateway.PreviewEvaluatorRequest\x1a!.gateway.PreviewEvaluatorResponse\">\x82\xd3\xe4\x93\x02\x38\"3/v1/{parent=accounts/*}/evaluators:previewEvaluator:\x01*\x12\x92\x01\n\x11PreviewEvaluation\x12!.gateway.PreviewEvaluationRequest\x1a\".gateway.PreviewEvaluationResponse\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/{name=accounts/*/evaluations/*}:preview:\x01*\x12\x81\x01\n\x0eTestEvaluation\x12\x1e.gateway.TestEvaluationRequest\x1a\".gateway.PreviewEvaluationResponse\"+\x82\xd3\xe4\x93\x02%\" /v1/{parent=accounts/*}:testeval:\x01*\x12K\n\x0fGetInferenceLog\x12\x1f.gateway.GetInferenceLogRequest\x1a\x15.gateway.InferenceLog\"\x00\x12\\\n\x11ListInferenceLogs\x12!.gateway.ListInferenceLogsRequest\x1a\".gateway.ListInferenceLogsResponse\"\x00\x12R\n\x12\x44\x65leteInferenceLog\x12\".gateway.DeleteInferenceLogRequest\x1a\x16.google.protobuf.Empty\"\x00\x12l\n\x1aGetDeploymentPrerequisites\x12*.gateway.GetDeploymentPrerequisitesRequest\x1a .gateway.DeploymentPrerequisites\"\x00\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.gateway_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_GATEWAY'].methods_by_name['GetAccount']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetAccount']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/{name=accounts/*}'
  _globals['_GATEWAY'].methods_by_name['ListAccounts']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListAccounts']._serialized_options = b'\202\323\344\223\002\016\022\014/v1/accounts'
  _globals['_GATEWAY'].methods_by_name['CreateBatchJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateBatchJob']._serialized_options = b'\202\323\344\223\002.\"!/v1/{parent=accounts/*}/batchJobs:\tbatch_job'
  _globals['_GATEWAY'].methods_by_name['GetBatchJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetBatchJob']._serialized_options = b'\202\323\344\223\002#\022!/v1/{name=accounts/*/batchJobs/*}'
  _globals['_GATEWAY'].methods_by_name['ListBatchJobs']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListBatchJobs']._serialized_options = b'\202\323\344\223\002#\022!/v1/{parent=accounts/*}/batchJobs'
  _globals['_GATEWAY'].methods_by_name['UpdateBatchJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UpdateBatchJob']._serialized_options = b'\202\323\344\223\00282+/v1/{batch_job.name=accounts/*/batchJobs/*}:\tbatch_job'
  _globals['_GATEWAY'].methods_by_name['DeleteBatchJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteBatchJob']._serialized_options = b'\202\323\344\223\002#*!/v1/{name=accounts/*/batchJobs/*}'
  _globals['_GATEWAY'].methods_by_name['BatchDeleteBatchJobs']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['BatchDeleteBatchJobs']._serialized_options = b'\202\323\344\223\0022\"-/v1/{parent=accounts/*}/batchJobs:batchDelete:\001*'
  _globals['_GATEWAY'].methods_by_name['CancelBatchJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CancelBatchJob']._serialized_options = b'\202\323\344\223\002-\"(/v1/{name=accounts/*/batchJobs/*}:cancel:\001*'
  _globals['_GATEWAY'].methods_by_name['CreateCluster']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateCluster']._serialized_options = b'\202\323\344\223\002%\" /v1/{parent=accounts/*}/clusters:\001*'
  _globals['_GATEWAY'].methods_by_name['GetCluster']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetCluster']._serialized_options = b'\202\323\344\223\002\"\022 /v1/{name=accounts/*/clusters/*}'
  _globals['_GATEWAY'].methods_by_name['ListClusters']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListClusters']._serialized_options = b'\202\323\344\223\002\"\022 /v1/{parent=accounts/*}/clusters'
  _globals['_GATEWAY'].methods_by_name['UpdateCluster']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UpdateCluster']._serialized_options = b'\202\323\344\223\00232(/v1/{cluster.name=accounts/*/clusters/*}:\007cluster'
  _globals['_GATEWAY'].methods_by_name['DeleteCluster']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteCluster']._serialized_options = b'\202\323\344\223\002\"* /v1/{name=accounts/*/clusters/*}'
  _globals['_GATEWAY'].methods_by_name['GetClusterConnectionInfo']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetClusterConnectionInfo']._serialized_options = b'\202\323\344\223\0024\0222/v1/{name=accounts/*/clusters/*}:getConnectionInfo'
  _globals['_GATEWAY'].methods_by_name['CreateEnvironment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateEnvironment']._serialized_options = b'\202\323\344\223\002)\"$/v1/{parent=accounts/*}/environments:\001*'
  _globals['_GATEWAY'].methods_by_name['GetEnvironment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetEnvironment']._serialized_options = b'\202\323\344\223\002&\022$/v1/{name=accounts/*/environments/*}'
  _globals['_GATEWAY'].methods_by_name['ListEnvironments']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListEnvironments']._serialized_options = b'\202\323\344\223\002&\022$/v1/{parent=accounts/*}/environments'
  _globals['_GATEWAY'].methods_by_name['UpdateEnvironment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UpdateEnvironment']._serialized_options = b'\202\323\344\223\002?20/v1/{environment.name=accounts/*/environments/*}:\013environment'
  _globals['_GATEWAY'].methods_by_name['DeleteEnvironment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteEnvironment']._serialized_options = b'\202\323\344\223\002&*$/v1/{name=accounts/*/environments/*}'
  _globals['_GATEWAY'].methods_by_name['BatchDeleteEnvironments']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['BatchDeleteEnvironments']._serialized_options = b'\202\323\344\223\0025\"0/v1/{parent=accounts/*}/environments:batchDelete:\001*'
  _globals['_GATEWAY'].methods_by_name['ConnectEnvironment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ConnectEnvironment']._serialized_options = b'\202\323\344\223\0021\",/v1/{name=accounts/*/environments/*}:connect:\001*'
  _globals['_GATEWAY'].methods_by_name['DisconnectEnvironment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DisconnectEnvironment']._serialized_options = b'\202\323\344\223\0024\"//v1/{name=accounts/*/environments/*}:disconnect:\001*'
  _globals['_GATEWAY'].methods_by_name['CreateSnapshot']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateSnapshot']._serialized_options = b'\202\323\344\223\002-\"!/v1/{parent=accounts/*}/snapshots:\010snapshot'
  _globals['_GATEWAY'].methods_by_name['GetSnapshot']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetSnapshot']._serialized_options = b'\202\323\344\223\002#\022!/v1/{name=accounts/*/snapshots/*}'
  _globals['_GATEWAY'].methods_by_name['ListSnapshots']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListSnapshots']._serialized_options = b'\202\323\344\223\002#\022!/v1/{parent=accounts/*}/snapshots'
  _globals['_GATEWAY'].methods_by_name['DeleteSnapshot']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteSnapshot']._serialized_options = b'\202\323\344\223\002#*!/v1/{name=accounts/*/snapshots/*}'
  _globals['_GATEWAY'].methods_by_name['GetBatchJobLogs']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetBatchJobLogs']._serialized_options = b'\202\323\344\223\002+\022)/v1/{name=accounts/*/batchJobs/*}:getLogs'
  _globals['_GATEWAY'].methods_by_name['CreateNodePool']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateNodePool']._serialized_options = b'\202\323\344\223\002&\"!/v1/{parent=accounts/*}/nodePools:\001*'
  _globals['_GATEWAY'].methods_by_name['GetNodePool']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetNodePool']._serialized_options = b'\202\323\344\223\002#\022!/v1/{name=accounts/*/nodePools/*}'
  _globals['_GATEWAY'].methods_by_name['ListNodePools']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListNodePools']._serialized_options = b'\202\323\344\223\002#\022!/v1/{parent=accounts/*}/nodePools'
  _globals['_GATEWAY'].methods_by_name['UpdateNodePool']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UpdateNodePool']._serialized_options = b'\202\323\344\223\00282+/v1/{node_pool.name=accounts/*/nodePools/*}:\tnode_pool'
  _globals['_GATEWAY'].methods_by_name['DeleteNodePool']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteNodePool']._serialized_options = b'\202\323\344\223\002#*!/v1/{name=accounts/*/nodePools/*}'
  _globals['_GATEWAY'].methods_by_name['BatchDeleteNodePools']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['BatchDeleteNodePools']._serialized_options = b'\202\323\344\223\0022\"-/v1/{parent=accounts/*}/nodePools:batchDelete:\001*'
  _globals['_GATEWAY'].methods_by_name['GetNodePoolStats']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetNodePoolStats']._serialized_options = b'\202\323\344\223\002,\022*/v1/{name=accounts/*/nodePools/*}:getStats'
  _globals['_GATEWAY'].methods_by_name['CreateUser']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateUser']._serialized_options = b'\202\323\344\223\002%\"\035/v1/{parent=accounts/*}/users:\004user'
  _globals['_GATEWAY'].methods_by_name['GetUser']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetUser']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/{name=accounts/*/users/*}'
  _globals['_GATEWAY'].methods_by_name['ListUsers']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListUsers']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/{parent=accounts/*}/users'
  _globals['_GATEWAY'].methods_by_name['UpdateUser']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UpdateUser']._serialized_options = b'\202\323\344\223\002*2\"/v1/{user.name=accounts/*/users/*}:\004user'
  _globals['_GATEWAY'].methods_by_name['ListAuditLogs']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListAuditLogs']._serialized_options = b'\202\323\344\223\002#\022!/v1/{parent=accounts/*}/auditLogs'
  _globals['_GATEWAY'].methods_by_name['CreateApiKey']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateApiKey']._serialized_options = b'\202\323\344\223\002$\"\037/v1/{parent=accounts/*}/apiKeys:\001*'
  _globals['_GATEWAY'].methods_by_name['ListApiKeys']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListApiKeys']._serialized_options = b'\202\323\344\223\002!\022\037/v1/{parent=accounts/*}/apiKeys'
  _globals['_GATEWAY'].methods_by_name['DeleteApiKey']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteApiKey']._serialized_options = b'\202\323\344\223\002+\"&/v1/{parent=accounts/*}/apiKeys:delete:\001*'
  _globals['_GATEWAY'].methods_by_name['CreateModel']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateModel']._serialized_options = b'\202\323\344\223\002#\"\036/v1/{parent=accounts/*}/models:\001*'
  _globals['_GATEWAY'].methods_by_name['GetModel']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetModel']._serialized_options = b'\202\323\344\223\002 \022\036/v1/{name=accounts/*/models/*}'
  _globals['_GATEWAY'].methods_by_name['ListModels']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListModels']._serialized_options = b'\202\323\344\223\002 \022\036/v1/{parent=accounts/*}/models'
  _globals['_GATEWAY'].methods_by_name['UpdateModel']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UpdateModel']._serialized_options = b'\202\323\344\223\002-2$/v1/{model.name=accounts/*/models/*}:\005model'
  _globals['_GATEWAY'].methods_by_name['DeleteModel']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteModel']._serialized_options = b'\202\323\344\223\002 *\036/v1/{name=accounts/*/models/*}'
  _globals['_GATEWAY'].methods_by_name['GetModelUploadEndpoint']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetModelUploadEndpoint']._serialized_options = b'\202\323\344\223\0025\"0/v1/{name=accounts/*/models/*}:getUploadEndpoint:\001*'
  _globals['_GATEWAY'].methods_by_name['GetModelDownloadEndpoint']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetModelDownloadEndpoint']._serialized_options = b'\202\323\344\223\0024\0222/v1/{name=accounts/*/models/*}:getDownloadEndpoint'
  _globals['_GATEWAY'].methods_by_name['ValidateModelUpload']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ValidateModelUpload']._serialized_options = b'\202\323\344\223\002/\022-/v1/{name=accounts/*/models/*}:validateUpload'
  _globals['_GATEWAY'].methods_by_name['ValidateModelConfig']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ValidateModelConfig']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/validateModelConfig:\001*'
  _globals['_GATEWAY'].methods_by_name['ImportModel']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ImportModel']._serialized_options = b'\202\323\344\223\002*\"%/v1/{name=accounts/*/models/*}:import:\001*'
  _globals['_GATEWAY'].methods_by_name['CreateDeployment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateDeployment']._serialized_options = b'\202\323\344\223\0021\"#/v1/{parent=accounts/*}/deployments:\ndeployment'
  _globals['_GATEWAY'].methods_by_name['GetDeployment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetDeployment']._serialized_options = b'\202\323\344\223\002%\022#/v1/{name=accounts/*/deployments/*}'
  _globals['_GATEWAY'].methods_by_name['ListDeployments']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListDeployments']._serialized_options = b'\202\323\344\223\002%\022#/v1/{parent=accounts/*}/deployments'
  _globals['_GATEWAY'].methods_by_name['UpdateDeployment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UpdateDeployment']._serialized_options = b'\202\323\344\223\002<2./v1/{deployment.name=accounts/*/deployments/*}:\ndeployment'
  _globals['_GATEWAY'].methods_by_name['DeleteDeployment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteDeployment']._serialized_options = b'\202\323\344\223\002%*#/v1/{name=accounts/*/deployments/*}'
  _globals['_GATEWAY'].methods_by_name['UndeleteDeployment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UndeleteDeployment']._serialized_options = b'\202\323\344\223\0021\",/v1/{name=accounts/*/deployments/*}:undelete:\001*'
  _globals['_GATEWAY'].methods_by_name['ScaleDeployment']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ScaleDeployment']._serialized_options = b'\202\323\344\223\002.2)/v1/{name=accounts/*/deployments/*}:scale:\001*'
  _globals['_GATEWAY'].methods_by_name['GetDeploymentMetrics']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetDeploymentMetrics']._serialized_options = b'\202\323\344\223\002-\022+/v1/{name=accounts/*/deployments/*}:metrics'
  _globals['_GATEWAY'].methods_by_name['CreateDeployedModel']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateDeployedModel']._serialized_options = b'\202\323\344\223\0028\"&/v1/{parent=accounts/*}/deployedModels:\016deployed_model'
  _globals['_GATEWAY'].methods_by_name['GetDeployedModel']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetDeployedModel']._serialized_options = b'\202\323\344\223\002(\022&/v1/{name=accounts/*/deployedModels/*}'
  _globals['_GATEWAY'].methods_by_name['ListDeployedModels']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListDeployedModels']._serialized_options = b'\202\323\344\223\002(\022&/v1/{parent=accounts/*}/deployedModels'
  _globals['_GATEWAY'].methods_by_name['UpdateDeployedModel']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UpdateDeployedModel']._serialized_options = b'\202\323\344\223\002G25/v1/{deployed_model.name=accounts/*/deployedModels/*}:\016deployed_model'
  _globals['_GATEWAY'].methods_by_name['DeleteDeployedModel']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteDeployedModel']._serialized_options = b'\202\323\344\223\002(*&/v1/{name=accounts/*/deployedModels/*}'
  _globals['_GATEWAY'].methods_by_name['CreateAwsIamRoleBinding']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateAwsIamRoleBinding']._serialized_options = b'\202\323\344\223\002B\"*/v1/{parent=accounts/*}/awsIamRoleBindings:\024aws_iam_role_binding'
  _globals['_GATEWAY'].methods_by_name['ListAwsIamRoleBindings']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListAwsIamRoleBindings']._serialized_options = b'\202\323\344\223\002,\022*/v1/{parent=accounts/*}/awsIamRoleBindings'
  _globals['_GATEWAY'].methods_by_name['DeleteAwsIamRoleBinding']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteAwsIamRoleBinding']._serialized_options = b'\202\323\344\223\002b\"J/v1/{aws_iam_role_binding.account_id=accounts/*}/awsIamRoleBindings:delete:\024aws_iam_role_binding'
  _globals['_GATEWAY'].methods_by_name['CreateNodePoolBinding']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateNodePoolBinding']._serialized_options = b'\202\323\344\223\002=\"(/v1/{parent=accounts/*}/nodePoolBindings:\021node_pool_binding'
  _globals['_GATEWAY'].methods_by_name['ListNodePoolBindings']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListNodePoolBindings']._serialized_options = b'\202\323\344\223\002*\022(/v1/{parent=accounts/*}/nodePoolBindings'
  _globals['_GATEWAY'].methods_by_name['DeleteNodePoolBinding']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteNodePoolBinding']._serialized_options = b'\202\323\344\223\002Z\"E/v1/{node_pool_binding.account_id=accounts/*}/nodePoolBindings:delete:\021node_pool_binding'
  _globals['_GATEWAY'].methods_by_name['CreateDataset']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateDataset']._serialized_options = b'\202\323\344\223\002%\" /v1/{parent=accounts/*}/datasets:\001*'
  _globals['_GATEWAY'].methods_by_name['GetDataset']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetDataset']._serialized_options = b'\202\323\344\223\002\"\022 /v1/{name=accounts/*/datasets/*}'
  _globals['_GATEWAY'].methods_by_name['ListDatasets']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListDatasets']._serialized_options = b'\202\323\344\223\002\"\022 /v1/{parent=accounts/*}/datasets'
  _globals['_GATEWAY'].methods_by_name['UpdateDataset']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UpdateDataset']._serialized_options = b'\202\323\344\223\00232(/v1/{dataset.name=accounts/*/datasets/*}:\007dataset'
  _globals['_GATEWAY'].methods_by_name['DeleteDataset']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteDataset']._serialized_options = b'\202\323\344\223\002\"* /v1/{name=accounts/*/datasets/*}'
  _globals['_GATEWAY'].methods_by_name['GetDatasetUploadEndpoint']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetDatasetUploadEndpoint']._serialized_options = b'\202\323\344\223\0027\"2/v1/{name=accounts/*/datasets/*}:getUploadEndpoint:\001*'
  _globals['_GATEWAY'].methods_by_name['ValidateDatasetUpload']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ValidateDatasetUpload']._serialized_options = b'\202\323\344\223\0024\"//v1/{name=accounts/*/datasets/*}:validateUpload:\001*'
  _globals['_GATEWAY'].methods_by_name['GetDatasetDownloadEndpoint']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetDatasetDownloadEndpoint']._serialized_options = b'\202\323\344\223\0026\0224/v1/{name=accounts/*/datasets/*}:getDownloadEndpoint'
  _globals['_GATEWAY'].methods_by_name['CreateEvaluator']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateEvaluator']._serialized_options = b'\202\323\344\223\002\'\"\"/v1/{parent=accounts/*}/evaluators:\001*'
  _globals['_GATEWAY'].methods_by_name['GetEvaluator']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetEvaluator']._serialized_options = b'\202\323\344\223\002$\022\"/v1/{name=accounts/*/evaluators/*}'
  _globals['_GATEWAY'].methods_by_name['ListEvaluators']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListEvaluators']._serialized_options = b'\202\323\344\223\002$\022\"/v1/{parent=accounts/*}/evaluators'
  _globals['_GATEWAY'].methods_by_name['DeleteEvaluator']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteEvaluator']._serialized_options = b'\202\323\344\223\002$*\"/v1/{name=accounts/*/evaluators/*}'
  _globals['_GATEWAY'].methods_by_name['CreateEvaluation']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateEvaluation']._serialized_options = b'\202\323\344\223\002(\"#/v1/{parent=accounts/*}/evaluations:\001*'
  _globals['_GATEWAY'].methods_by_name['GetEvaluation']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetEvaluation']._serialized_options = b'\202\323\344\223\002%\022#/v1/{name=accounts/*/evaluations/*}'
  _globals['_GATEWAY'].methods_by_name['ListEvaluations']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListEvaluations']._serialized_options = b'\202\323\344\223\002%\022#/v1/{parent=accounts/*}/evaluations'
  _globals['_GATEWAY'].methods_by_name['DeleteEvaluation']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteEvaluation']._serialized_options = b'\202\323\344\223\002%*#/v1/{name=accounts/*/evaluations/*}'
  _globals['_GATEWAY'].methods_by_name['CreateEvaluationJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateEvaluationJob']._serialized_options = b'\202\323\344\223\002+\"&/v1/{parent=accounts/*}/evaluationJobs:\001*'
  _globals['_GATEWAY'].methods_by_name['GetEvaluationJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetEvaluationJob']._serialized_options = b'\202\323\344\223\002(\022&/v1/{name=accounts/*/evaluationJobs/*}'
  _globals['_GATEWAY'].methods_by_name['ListEvaluationJobs']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListEvaluationJobs']._serialized_options = b'\202\323\344\223\002(\022&/v1/{parent=accounts/*}/evaluationJobs'
  _globals['_GATEWAY'].methods_by_name['DeleteEvaluationJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteEvaluationJob']._serialized_options = b'\202\323\344\223\002(*&/v1/{name=accounts/*/evaluationJobs/*}'
  _globals['_GATEWAY'].methods_by_name['CreateFineTuningJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateFineTuningJob']._serialized_options = b'\202\323\344\223\0029\"&/v1/{parent=accounts/*}/fineTuningJobs:\017fine_tuning_job'
  _globals['_GATEWAY'].methods_by_name['GetFineTuningJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetFineTuningJob']._serialized_options = b'\202\323\344\223\002(\022&/v1/{name=accounts/*/fineTuningJobs/*}'
  _globals['_GATEWAY'].methods_by_name['ListFineTuningJobs']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListFineTuningJobs']._serialized_options = b'\202\323\344\223\002(\022&/v1/{parent=accounts/*}/fineTuningJobs'
  _globals['_GATEWAY'].methods_by_name['UpdateFineTuningJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UpdateFineTuningJob']._serialized_options = b'\202\323\344\223\002I26/v1/{fine_tuning_job.name=accounts/*/fineTuningJobs/*}:\017fine_tuning_job'
  _globals['_GATEWAY'].methods_by_name['DeleteFineTuningJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteFineTuningJob']._serialized_options = b'\202\323\344\223\002(*&/v1/{name=accounts/*/fineTuningJobs/*}'
  _globals['_GATEWAY'].methods_by_name['CreateSupervisedFineTuningJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateSupervisedFineTuningJob']._serialized_options = b'\202\323\344\223\002N\"0/v1/{parent=accounts/*}/supervisedFineTuningJobs:\032supervised_fine_tuning_job'
  _globals['_GATEWAY'].methods_by_name['GetSupervisedFineTuningJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetSupervisedFineTuningJob']._serialized_options = b'\202\323\344\223\0022\0220/v1/{name=accounts/*/supervisedFineTuningJobs/*}'
  _globals['_GATEWAY'].methods_by_name['ListSupervisedFineTuningJobs']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListSupervisedFineTuningJobs']._serialized_options = b'\202\323\344\223\0022\0220/v1/{parent=accounts/*}/supervisedFineTuningJobs'
  _globals['_GATEWAY'].methods_by_name['DeleteSupervisedFineTuningJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteSupervisedFineTuningJob']._serialized_options = b'\202\323\344\223\0022*0/v1/{name=accounts/*/supervisedFineTuningJobs/*}'
  _globals['_GATEWAY'].methods_by_name['CreateReinforcementFineTuningJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateReinforcementFineTuningJob']._serialized_options = b'\202\323\344\223\002T\"3/v1/{parent=accounts/*}/reinforcementFineTuningJobs:\035reinforcement_fine_tuning_job'
  _globals['_GATEWAY'].methods_by_name['GetReinforcementFineTuningJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetReinforcementFineTuningJob']._serialized_options = b'\202\323\344\223\0025\0223/v1/{name=accounts/*/reinforcementFineTuningJobs/*}'
  _globals['_GATEWAY'].methods_by_name['ListReinforcementFineTuningJobs']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListReinforcementFineTuningJobs']._serialized_options = b'\202\323\344\223\0025\0223/v1/{parent=accounts/*}/reinforcementFineTuningJobs'
  _globals['_GATEWAY'].methods_by_name['DeleteReinforcementFineTuningJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteReinforcementFineTuningJob']._serialized_options = b'\202\323\344\223\0025*3/v1/{name=accounts/*/reinforcementFineTuningJobs/*}'
  _globals['_GATEWAY'].methods_by_name['CreatePeftMergeJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreatePeftMergeJob']._serialized_options = b'\202\323\344\223\0027\"%/v1/{parent=accounts/*}/PeftMergeJobs:\016peft_merge_job'
  _globals['_GATEWAY'].methods_by_name['GetPeftMergeJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetPeftMergeJob']._serialized_options = b'\202\323\344\223\002\'\022%/v1/{name=accounts/*/PeftMergeJobs/*}'
  _globals['_GATEWAY'].methods_by_name['ListPeftMergeJobs']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListPeftMergeJobs']._serialized_options = b'\202\323\344\223\002\'\022%/v1/{parent=accounts/*}/PeftMergeJobs'
  _globals['_GATEWAY'].methods_by_name['DeletePeftMergeJob']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeletePeftMergeJob']._serialized_options = b'\202\323\344\223\002\'*%/v1/{name=accounts/*/PeftMergeJobs/*}'
  _globals['_GATEWAY'].methods_by_name['CreateSecret']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['CreateSecret']._serialized_options = b'\202\323\344\223\002)\"\037/v1/{parent=accounts/*}/secrets:\006secret'
  _globals['_GATEWAY'].methods_by_name['GetSecret']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['GetSecret']._serialized_options = b'\202\323\344\223\002!\022\037/v1/{name=accounts/*/secrets/*}'
  _globals['_GATEWAY'].methods_by_name['ListSecrets']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ListSecrets']._serialized_options = b'\202\323\344\223\002!\022\037/v1/{parent=accounts/*}/secrets'
  _globals['_GATEWAY'].methods_by_name['UpdateSecret']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['UpdateSecret']._serialized_options = b'\202\323\344\223\00202&/v1/{secret.name=accounts/*/secrets/*}:\006secret'
  _globals['_GATEWAY'].methods_by_name['DeleteSecret']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['DeleteSecret']._serialized_options = b'\202\323\344\223\002!*\037/v1/{name=accounts/*/secrets/*}'
  _globals['_GATEWAY'].methods_by_name['ValidateAssertions']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['ValidateAssertions']._serialized_options = b'\202\323\344\223\002;\"6/v1/{parent=accounts/*}/evaluations:validateAssertions:\001*'
  _globals['_GATEWAY'].methods_by_name['PreviewEvaluator']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['PreviewEvaluator']._serialized_options = b'\202\323\344\223\0028\"3/v1/{parent=accounts/*}/evaluators:previewEvaluator:\001*'
  _globals['_GATEWAY'].methods_by_name['PreviewEvaluation']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['PreviewEvaluation']._serialized_options = b'\202\323\344\223\0020\"+/v1/{name=accounts/*/evaluations/*}:preview:\001*'
  _globals['_GATEWAY'].methods_by_name['TestEvaluation']._loaded_options = None
  _globals['_GATEWAY'].methods_by_name['TestEvaluation']._serialized_options = b'\202\323\344\223\002%\" /v1/{parent=accounts/*}:testeval:\001*'
  _globals['_GATEWAY']._serialized_start=1139
  _globals['_GATEWAY']._serialized_end=22278
# @@protoc_insertion_point(module_scope)



from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from . import user_pb2 as _user_pb2
from . import wandb_pb2 as _wandb_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Account(_message.Message):
    __slots__ = ("name", "display_name", "create_time", "intended_use", "prometheus_endpoint", "athena_cost_usage_report_bucket", "account_type", "email", "state", "status", "suspend_state", "stripe_customer_id", "oidc_issuer_url", "oidc_client_id", "cognito_domain", "wandb_config", "update_time")
    class AccountType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ACCOUNT_TYPE_UNSPECIFIED: _ClassVar[Account.AccountType]
        DEVELOPER: _ClassVar[Account.AccountType]
        ENTERPRISE: _ClassVar[Account.AccountType]
        BUSINESS: _ClassVar[Account.AccountType]
    ACCOUNT_TYPE_UNSPECIFIED: Account.AccountType
    DEVELOPER: Account.AccountType
    ENTERPRISE: Account.AccountType
    BUSINESS: Account.AccountType
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATE_UNSPECIFIED: _ClassVar[Account.State]
        CREATING: _ClassVar[Account.State]
        READY: _ClassVar[Account.State]
        UPDATING: _ClassVar[Account.State]
        DELETING: _ClassVar[Account.State]
    STATE_UNSPECIFIED: Account.State
    CREATING: Account.State
    READY: Account.State
    UPDATING: Account.State
    DELETING: Account.State
    class SuspendState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNSUSPENDED: _ClassVar[Account.SuspendState]
        FAILED_PAYMENTS: _ClassVar[Account.SuspendState]
        CREDIT_DEPLETED: _ClassVar[Account.SuspendState]
        MONTHLY_SPEND_LIMIT_EXCEEDED: _ClassVar[Account.SuspendState]
    UNSUSPENDED: Account.SuspendState
    FAILED_PAYMENTS: Account.SuspendState
    CREDIT_DEPLETED: Account.SuspendState
    MONTHLY_SPEND_LIMIT_EXCEEDED: Account.SuspendState
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    INTENDED_USE_FIELD_NUMBER: _ClassVar[int]
    PROMETHEUS_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    ATHENA_COST_USAGE_REPORT_BUCKET_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_TYPE_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUSPEND_STATE_FIELD_NUMBER: _ClassVar[int]
    STRIPE_CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    OIDC_ISSUER_URL_FIELD_NUMBER: _ClassVar[int]
    OIDC_CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    COGNITO_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    WANDB_CONFIG_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    create_time: _timestamp_pb2.Timestamp
    intended_use: str
    prometheus_endpoint: str
    athena_cost_usage_report_bucket: str
    account_type: Account.AccountType
    email: str
    state: Account.State
    status: _status_pb2.Status
    suspend_state: Account.SuspendState
    stripe_customer_id: str
    oidc_issuer_url: str
    oidc_client_id: str
    cognito_domain: str
    wandb_config: _wandb_pb2.WandbConfig
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., intended_use: _Optional[str] = ..., prometheus_endpoint: _Optional[str] = ..., athena_cost_usage_report_bucket: _Optional[str] = ..., account_type: _Optional[_Union[Account.AccountType, str]] = ..., email: _Optional[str] = ..., state: _Optional[_Union[Account.State, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., suspend_state: _Optional[_Union[Account.SuspendState, str]] = ..., stripe_customer_id: _Optional[str] = ..., oidc_issuer_url: _Optional[str] = ..., oidc_client_id: _Optional[str] = ..., cognito_domain: _Optional[str] = ..., wandb_config: _Optional[_Union[_wandb_pb2.WandbConfig, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateAccountRequest(_message.Message):
    __slots__ = ("account", "account_id", "wait", "user")
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    WAIT_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    account: Account
    account_id: str
    wait: bool
    user: _user_pb2.User
    def __init__(self, account: _Optional[_Union[Account, _Mapping]] = ..., account_id: _Optional[str] = ..., wait: bool = ..., user: _Optional[_Union[_user_pb2.User, _Mapping]] = ...) -> None: ...

class GetAccountRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListAccountsRequest(_message.Message):
    __slots__ = ("page_size", "page_token", "filter", "order_by", "show_all")
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    SHOW_ALL_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    filter: str
    order_by: str
    show_all: bool
    def __init__(self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ..., show_all: bool = ...) -> None: ...

class ListAccountsResponse(_message.Message):
    __slots__ = ("accounts", "next_page_token", "total_size")
    ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    accounts: _containers.RepeatedCompositeFieldContainer[Account]
    next_page_token: str
    total_size: int
    def __init__(self, accounts: _Optional[_Iterable[_Union[Account, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class UpdateAccountRequest(_message.Message):
    __slots__ = ("account", "update_mask")
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    account: Account
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, account: _Optional[_Union[Account, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class DeleteAccountRequest(_message.Message):
    __slots__ = ("name", "force")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    name: str
    force: bool
    def __init__(self, name: _Optional[str] = ..., force: bool = ...) -> None: ...
